==> haskell-pid1-0.1.2.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pid1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pid1
version:              0.1.2.0
visibility:           public
id:                   pid1-0.1.2.0-LW5M7L7WkdTItCIgVdjQT8
key:                  pid1-0.1.2.0-LW5M7L7WkdTItCIgVdjQT8
license:              MIT
copyright:            2016 Michael Snoyman
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/pid1#readme
synopsis:
    Do signal handling and orphan reaping for Unix PID1 init processes

description:
    Please see README.md or view Haddocks at <https://www.stackage.org/package/pid1>

category:             System
abi:                  1772ceede495eb648db3d50bc528ed50
exposed:              True
exposed-modules:      System.Process.PID1
import-dirs:          /usr/lib/ghc-8.8.1/site-local/pid1-0.1.2.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/pid1-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/pid1-0.1.2.0
hs-libraries:         HSpid1-0.1.2.0-LW5M7L7WkdTItCIgVdjQT8
depends:
    base-4.13.0.0 directory-1.3.3.2 process-1.6.5.1 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pid1/html/pid1.haddock
haddock-html:         /usr/share/doc/haskell-pid1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pid1-0.1.2.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pid1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pid1
version:              0.1.2.0
visibility:           public
id:                   pid1-0.1.2.0-BMBkqcqUnOGEPXxyZ8rEVU
key:                  pid1-0.1.2.0-BMBkqcqUnOGEPXxyZ8rEVU
license:              MIT
copyright:            2016 Michael Snoyman
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/pid1#readme
synopsis:
    Do signal handling and orphan reaping for Unix PID1 init processes

description:
    Please see README.md or view Haddocks at <https://www.stackage.org/package/pid1>

category:             System
abi:                  27a98da66a1cafb3bed3d57039555673
exposed:              True
exposed-modules:      System.Process.PID1
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pid1-0.1.2.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pid1-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pid1-0.1.2.0
hs-libraries:         HSpid1-0.1.2.0-BMBkqcqUnOGEPXxyZ8rEVU
depends:
    base-4.13.0.0 directory-1.3.6.0 process-1.6.8.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pid1/html/pid1.haddock
haddock-html:         /usr/share/doc/haskell-pid1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
